==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/KeyEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { KeyEventArgsDescription } from "./KeyEventArgsDescription";
/**
 * @hidden
 */
export let KeyEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class KeyEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (KeyEventArgsDescriptionMetadata.a == null) {
                KeyEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                KeyEventArgsDescriptionMetadata.c(KeyEventArgsDescriptionMetadata.a);
            }
            if (a.j(KeyEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(KeyEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            KeyEventArgsDescriptionMetadata.b(a);
            a.aa("KeyEventArgs", () => new KeyEventArgsDescription());
            a.z("KeyEventArgs", KeyEventArgsDescriptionMetadata.a);
        }
    }
    KeyEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(KeyEventArgsDescriptionMetadata, 'KeyEventArgsDescriptionMetadata');
    KeyEventArgsDescriptionMetadata.a = null;
    return KeyEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/KeyEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { KeyEventArgsDescription } from "./KeyEventArgsDescription";
/**
 * @hidden
 */
export let KeyEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class KeyEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (KeyEventArgsDescriptionMetadata.a == null) {
                KeyEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                KeyEventArgsDescriptionMetadata.c(KeyEventArgsDescriptionMetadata.a);
            }
            if (a.k(KeyEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(KeyEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            KeyEventArgsDescriptionMetadata.b(a);
            a.ac("KeyEventArgs", () => new KeyEventArgsDescription());
            a.ab("KeyEventArgs", KeyEventArgsDescriptionMetadata.a);
        }
    }
    KeyEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(KeyEventArgsDescriptionMetadata, 'KeyEventArgsDescriptionMetadata');
    KeyEventArgsDescriptionMetadata.a = null;
    return KeyEventArgsDescriptionMetadata;
})();
